@@ -1,6 +1,6 @@
 "dataquality"
 
-__version__ = "v0.0.5"
+__version__ = "v0.0.6"
 
 import resource
 
@@ -10,6 +10,7 @@ from dataquality.core.auth import login
 from dataquality.core.finish import finish
 from dataquality.core.init import init
 from dataquality.core.log import (
+    docs,
     get_data_logger,
     get_model_logger,
     log_batch_input_data,
@@ -47,6 +48,10 @@ __all__ = [
     "get_data_logger",
     "get_model_logger",
     "set_tasks_for_run",
+    "docs",
 ]
 
-resource.setrlimit(resource.RLIMIT_NOFILE, (65535, 65535))
+try:
+    resource.setrlimit(resource.RLIMIT_NOFILE, (65535, 65535))
+except ValueError:  # The users limit is higher than our max, which is OK
+    pass
