@@ -1,5 +1,6 @@
 __data_schema_version__ = 1
 from dataquality.schemas.job import ProcName
+from dataquality.schemas.request_type import RequestType
 from dataquality.schemas.route import Route
 
-__all__ = ["ProcName", "Route"]
+__all__ = ["ProcName", "RequestType", "Route"]
